Crate curve_similarities

Crate curve_similarities 

Enums

DistMetric
DistMetric represents the possible pairwise distance metrics for elements to be used when calculating the Frechet distance and Dynamic Time Warping

Traits

DistMatCalc
DistMatCalc defines a trait for types for which can be computed a pairwise distance matrix
PairDiff
PairDiff trait provides pairwise distance for various primitive types

Functions

area_between_two_curves
Calculates the distance between two curves according to: Jekel, C. F., Venter, G., Venter, M. P., Stander, N., & Haftka, R. T. (2018) “Similarity measures for identifying material parameters from hysteresis loops using inverse analysis”
curve_len_measure
Calculates the distance between two curves according to: A Andrade-Campos, R De-Carvalho, and R A F Valente “Novel criteria for determination of material model parameters”
dtw
Calculates the Dynamic Time Warping
frechet
Calculates the Frechet distance between two curves